@@ -37,7 +37,7 @@ class TQLabel;
  */
 class PMJuliaFractalEdit : public PMSolidObjectEdit
 {
-   Q_OBJECT
+   TQ_OBJECT
   
    typedef PMSolidObjectEdit Base;
 public:
